==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PropertyReferenceFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { PropertyReferenceFilterExpressionDescription } from "./PropertyReferenceFilterExpressionDescription";
/**
 * @hidden
 */
export let PropertyReferenceFilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyReferenceFilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyReferenceFilterExpressionDescriptionMetadata.a == null) {
                PropertyReferenceFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyReferenceFilterExpressionDescriptionMetadata.c(PropertyReferenceFilterExpressionDescriptionMetadata.a);
            }
            if (a.k(PropertyReferenceFilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(PropertyReferenceFilterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("PropertyReference", "String");
        }
        static d(a) {
            PropertyReferenceFilterExpressionDescriptionMetadata.b(a);
            a.ac("PropertyReferenceFilterExpression", () => new PropertyReferenceFilterExpressionDescription());
            a.ab("PropertyReferenceFilterExpression", PropertyReferenceFilterExpressionDescriptionMetadata.a);
        }
    }
    PropertyReferenceFilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyReferenceFilterExpressionDescriptionMetadata, 'PropertyReferenceFilterExpressionDescriptionMetadata');
    PropertyReferenceFilterExpressionDescriptionMetadata.a = null;
    return PropertyReferenceFilterExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/PropertyReferenceFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { PropertyReferenceFilterExpressionDescription } from "./PropertyReferenceFilterExpressionDescription";
/**
 * @hidden
 */
export let PropertyReferenceFilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyReferenceFilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyReferenceFilterExpressionDescriptionMetadata.a == null) {
                PropertyReferenceFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyReferenceFilterExpressionDescriptionMetadata.c(PropertyReferenceFilterExpressionDescriptionMetadata.a);
            }
            if (a.k(PropertyReferenceFilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(PropertyReferenceFilterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("PropertyReference", "String");
        }
        static d(a) {
            PropertyReferenceFilterExpressionDescriptionMetadata.b(a);
            a.ae("PropertyReferenceFilterExpression", () => new PropertyReferenceFilterExpressionDescription());
            a.ad("PropertyReferenceFilterExpression", PropertyReferenceFilterExpressionDescriptionMetadata.a);
        }
    }
    PropertyReferenceFilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyReferenceFilterExpressionDescriptionMetadata, 'PropertyReferenceFilterExpressionDescriptionMetadata');
    PropertyReferenceFilterExpressionDescriptionMetadata.a = null;
    return PropertyReferenceFilterExpressionDescriptionMetadata;
})();
